@@ -9,6 +9,7 @@ from werkzeug.routing import Map, Rule
 
 from restfx.globs import _app_ctx_stack
 from restfx.util import ContextStore, utils
+from . import __meta__
 from .http import HttpRequest, NotFound, ServerError
 from .middleware import MiddlewareManager
 from .routes import Collector
@@ -82,11 +83,19 @@ class App:
         :param api_page_assets: 接口页面上，需要自定义的JS和CSS以及其它资源 (通过 static 托管，此接口仅填写地址)
         :param allowed_route_meta: 路由装饰器上，指定允许使用的自定义元数据参数。当此值为 None 时，不限制。
         """
+        # 更新系统路径
+        if app_root not in sys.path:
+            sys.path.insert(0, app_root)
+
         from .config import AppConfig
         from .routes import ApiPage
         from .routes import Router
         from .util import Logger
 
+        # 上下文需要先创建，以便后续的模块能直接使用
+        self.context = AppContext(self)
+        self.context.push()
+
         self.id = app_id or str(uuid.uuid4())
         self._logger = Logger(app_id)
 
@@ -97,7 +106,7 @@ class App:
                                 api_page_expanded, api_page_cache, api_page_addition,
                                 api_page_header, api_page_footer, api_page_assets,
                                 allowed_route_meta)
-        self.config.middleware_manager = MiddlewareManager(self.id, self.config)
+        self.config.middleware_manager = MiddlewareManager(self.config)
         self._api_prefix = api_prefix
         self._router = Router(self.config)
         self._api_page = ApiPage(self.config)
@@ -116,14 +125,20 @@ class App:
 
         Collector.create(app_id, app_root, append_slash)
 
-        self.context = AppContext(self)
-        self.context.push()
+        from restfx import commands
+        commands.register('persist', self.persist, 'Persist routes info into file', '[filename] [encoding]')
 
     def dispose(self):
         self.config.middleware_manager.handle_shutdown()
 
         del self.config.middleware_manager
 
+        for plugin in self.config.plugins:
+            try:
+                plugin.destroy()
+            except Exception as e:
+                self._logger.error('Failed to destroy plugin %r' % plugin.__name__, e)
+
         self._logger.info('App "%s" is shutting down' % self.id)
         Collector.destroy(self.id)
         self.context.pop()
@@ -164,23 +179,32 @@ class App:
                 else:
                     response = NotFound()
         except Exception as e:
-            msg = utils.get_exception_info(e)
-            if request:
-                msg = 'Error occurred during handling request %r:\n\t%s' % (request.path, msg)
-
-            self._logger.error(msg)
-
-            if isinstance(e, SuperNotFound):
+            # 忽略静态资源请求的 .js.map/.css.map 文件
+            if request and (request.path.lower().endswith('.js.map') or request.path.lower().endswith('.css.map')):
                 response = NotFound()
-            elif self.config.debug:
-                response = ServerError(msg.replace('<', '&lt;').replace('>', '&gt;'))
             else:
-                response = ServerError()
+                msg = utils.get_exception_info(e)
+                if request:
+                    msg = 'Error occurred during handling request %r:\n\t%s' % (request.path, msg)
+
+                self._logger.error(msg)
+
+                if isinstance(e, SuperNotFound):
+                    response = NotFound()
+                elif self.config.debug:
+                    response = ServerError(msg.replace('<', '&lt;').replace('>', '&gt;'))
+                else:
+                    response = ServerError()
         finally:
             result = self.config.middleware_manager.handle_leaving(request, response)
             if result:
                 response = result
             request.context().pop()
+            import werkzeug
+            sv = sys.version_info
+            response.headers['server'] = '%s/%s werkzeug/%s Python/%s' % (
+                __meta__.name, __meta__.version, werkzeug.__version__, '%s.%s.%s' % (sv[0], sv[1], sv[2])
+            )
         return response(environ, start_response)
 
     def __call__(self, environ, start_response):
@@ -254,7 +278,7 @@ class App:
         #     self._logger.warning('The port "%s" is not available, pick another one instead.' % port)
         #     exit(1)
 
-            # 支持 空串和 * 标志
+        # 支持 空串和 * 标志
         if host in [None, '', '*']:
             host = '0.0.0.0'
 
@@ -291,14 +315,16 @@ class App:
         """
         return Collector.get(self.id).collect(self.config.routes_map)
 
-    def persist(self, filename: str = '', encoding='utf8'):
+    def persist(self, filename: str = 'dist/routes_map.py', encoding='utf8'):
         """
         持久化路由信息到文件
-        :param filename: 不指定此值时，此函数会返回路由文件内容
-        :param encoding:
+        :param encoding: 文件编码
+        :param filename: 输出的路由文件名称
         :return:
         """
-        return Collector.get(self.id).persist(self.config.routes_map, filename, encoding)
+        routes_file = os.path.basename(filename)
+        routes_dir = os.path.dirname(filename)
+        return Collector.get(self.id).persist(self.config.routes_map, routes_file, routes_dir, encoding)
 
     def set_logger(self, logger):
         """
@@ -365,47 +391,56 @@ class App:
 
     def register_routes(self, routes: list):
         """
-        手动注册路由列表
+        注册路由列表。一般来说，应当通过以下方法调用：
+
+        from dist import routes_map
+
+        app.register_routes(routes_map.routes)
+
         :param routes: 其每一项都应该是一个 list, 元素依次为 method: str, path: str, handler: FunctionType
         :return:
         """
-        for route in routes:
-            self.register_route(*route)
+        for handler, api_info in routes:
+            from .util.func_util import FunctionDescription
+
+            method = api_info['method']
+            path = api_info['path']
+
+            rid = '%s#%s' % (path, method.lower())
+            if rid in self._router.production_routes:
+                self._logger.warning('Duplicated route %s %s' % (method, path))
+
+            desc = FunctionDescription(handler)
+            self._router.production_routes[rid] = {
+                'func': handler,
+                'args': desc.arguments
+            }
+            self.config.docs.append(api_info)
+
         return self
 
-    def register_route(self, method: str, path: str, handler: FunctionType):
-        """
-        手动注册路由
-        :param path:
-        :param method:
-        :param handler:
-        :return:
-        """
-        from .util.func_util import FunctionDescription
-
-        rid = '%s#%s' % (path, method.lower())
-        if rid in self._router.production_routes:
-            self._logger.warning('Duplicated route %s %s' % (method, path))
-
-        desc = FunctionDescription(handler)
-        self._router.production_routes[rid] = {
-            'func': handler,
-            'args': desc.arguments
-        }
-        return self
-
-    def register_middleware(self, *middlewares):
+    def register_middleware(self, *middlewares, index: int = -1):
         """
         注册中间件，注册的中间件将按顺序执行
         :param middlewares: 中间件实例列表
+        :param index: 要将包插入的位置，指定为 -1 表示放到最后
         :return:
         """
         from restfx.middleware import MiddlewareBase
 
         for middleware in middlewares:
             assert isinstance(middleware, MiddlewareBase)
-            self.config.middlewares.append(middleware)
-            self.config.reversed_middlewares.insert(0, middleware)
+            if index == -1:
+                self.config.middlewares.append(middleware)
+                self.config.reversed_middlewares.insert(0, middleware)
+            else:
+                self.config.middlewares.insert(index, middleware)
+                if index == 0:
+                    self.config.reversed_middlewares.append(middleware)
+                else:
+                    self.config.reversed_middlewares.insert(-index, middleware)
+                # 每添加一个，将 index 后移动一个位置
+                index += 1
             # 调用中间件，标记中间件的启动
             middleware.on_startup(self)
 
@@ -420,6 +455,31 @@ class App:
         self.config.injections.update(**kwargs)
         return self
 
+    def register_plugins(self, *plugins):
+        """
+        注册插件，插件没有顺序之分
+        :param plugins: 插件实例列表
+        :return:
+        """
+        from restfx.plugin import PluginBase
+
+        for plugin in plugins:
+            assert isinstance(plugin, PluginBase)
+            self.config.plugins.append(plugin)
+            # 调用插件，标记中间件的启动
+            plugin.setup(self)
+
+        return self
+
+    @classmethod
+    def register_command(cls, command: str, handler: FunctionType, description: str):
+        from restfx import commands
+        commands.register(command, handler, description)
+
+    def test_command(self):
+        from restfx import commands
+        return commands.execute(*sys.argv, working_dir=self.config.ROOT)
+
     @classmethod
     def get(cls, app_id: str):
         """
