@@ -1,9 +1,11 @@
 import uuid
+
 from werkzeug import Request
 from werkzeug.datastructures import ImmutableDict, ImmutableMultiDict, FileStorage, MultiDict
 
-from restfx.util import ContextStore
 from restfx.globs import _request_ctx_stack, _app_ctx_stack
+from restfx.session import HttpSession
+from restfx.util import ContextStore
 
 
 def _get_request_data(data: MultiDict) -> ImmutableDict:
@@ -22,9 +24,10 @@ def _get_request_data(data: MultiDict) -> ImmutableDict:
 
 
 def _get_files(files):
-    if not files:
-        return None
     result = {}
+    if not files:
+        return result
+
     for name in files:
         file = files.get(name)
         result[name] = HttpFile.inherit(file)
@@ -39,7 +42,7 @@ class RequestContext:
         self.ref_count = 0
 
     @property
-    def session(self):
+    def session(self) -> HttpSession:
         return self.request.session
 
     def push(self):
@@ -69,7 +72,7 @@ class RequestContext:
 class HttpRequest(Request):
     def __init__(self, environ, app):
         super().__init__(environ)
-        self.id = str(uuid.uuid4())
+        self.id = uuid.uuid4().hex
         self.app = app
         self.app_id = app.id
         self.GET = _get_request_data(self.args)
@@ -78,6 +81,9 @@ class HttpRequest(Request):
         self.FILES = _get_files(self.files)
         self.COOKIES = self.cookies
         self.session = None
+        """
+        :type: HttpSession
+        """
         self._injections = {}
         # 用于存放一些用户的数据
         self._user_data = {}
@@ -127,7 +133,7 @@ class HttpRequest(Request):
         if not match:
             from restfx.util import Logger
             from restfx.http import BadRequest
-            Logger.get(self.app_id).warning('Invalid value of request header "range": %r' % request_range)
+            Logger.current().warning('Invalid value of request header "range": %r' % request_range)
             return BadRequest()
 
         return match.group('unit'), int(match.group('start')), int(match.group('end') or 0)
