@@ -61,7 +61,7 @@ def route(
             if not isinstance(request, HttpRequest) or not isinstance(handler_args, OrderedDict):
                 return handler(*args_def)
 
-            config = AppConfig.get(request.app_id)
+            config = AppConfig.current()
 
             meta = RouteMeta(
                 handler,
@@ -154,7 +154,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig,
     # 执行校验
     result = validate_args(validators, actual_args)
     if result is not None:
-        return BadRequest(result, content_type='text/plain')
+        return handle_response(BadRequest(result, content_type='text/plain'))
 
     # 调用路由函数
     arg_len = len(handler_args)
@@ -167,7 +167,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig,
     except Exception as e:
         from restfx.util import utils
         msg = 'Error occurred during executing the route handler: %s' % str(e)
-        Logger.get(config.app_id).error(utils.get_exception_info(e, msg), e)
+        Logger.current().error(utils.get_exception_info(e, msg), e)
         if config.debug:
             raise e
         return handle_response(ServerError())
@@ -193,7 +193,7 @@ def _process_json_args(request: HttpRequest, config: AppConfig):
     try:
         request.BODY = json.loads(body.decode())
     except Exception as e:
-        Logger.get(config.app_id).warning('Failed to deserialize request body: %s' % str(e))
+        Logger.current().warning('Failed to deserialize request body: %s' % str(e))
 
 
 def _get_parameter_str(args_def: OrderedDict):
@@ -211,18 +211,30 @@ def _get_value(data: MultiDict, name: str, arg_spec: ArgumentSpecification):
     alias = arg_spec.alias
     # 提供对 a[]=1&a[]=2 的支持
     name_arr = name + '[]'
-    alias_arr = alias + '[]' if alias else None
     is_arr = False
     if name in data:
         result = False, data.getlist(name)
-    elif alias and alias in data:
-        result = False, data.getlist(alias)
+    elif alias:
+        result = None, None
+        for an in alias:
+            an_arr = an + '[]'
+            if an in data:
+                result = False, data.getlist(an)
+                break
+            if an_arr in data:
+                is_arr = True
+                result = False, data.getlist(an_arr)
+                break
+        if result[0] is None:
+            if arg_spec.has_default:
+                # 使用默认值
+                result = True, arg_spec.default
+            else:
+                # 缺少无默认值的参数
+                result = None, None
     elif name_arr in data:
         is_arr = True
         result = False, data.getlist(name_arr)
-    elif alias_arr and alias_arr in data:
-        is_arr = True
-        result = False, data.getlist(alias_arr)
     elif arg_spec.has_default:
         # 使用默认值
         result = True, arg_spec.default
@@ -288,7 +300,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
 
         msg = 'Cannot parse value "%s" as type "%s for parameter %s". (expected: true/false)' % (
             (arg_value, arg_spec.annotation_name, arg_name))
-        Logger.get(config.app_id).warning(msg)
+        Logger.current().warning(msg)
         return BadRequest(msg)
 
     # 当声明的参数类型是枚举类型时，遍历枚举项，同时将枚举名称与值进行处理
@@ -298,7 +310,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
             msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
                 arg_value, arg_spec.annotation_name, arg_name
             )
-            Logger.get(config.app_id).warning(msg)
+            Logger.current().warning(msg)
             return BadRequest(msg)
 
         return result
@@ -321,7 +333,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
                 msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
                     arg_value, arg_spec.annotation_name, arg_name
                 )
-                Logger.get(config.app_id).warning(msg)
+                Logger.current().warning(msg)
                 return BadRequest(msg)
 
         # 类型一致，直接使用
@@ -334,7 +346,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
         msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
             arg_value, arg_spec.annotation_name, arg_name
         )
-        Logger.get(config.app_id).warning(msg)
+        Logger.current().warning(msg)
         return BadRequest(msg)
 
 
@@ -359,7 +371,7 @@ def _fill_session(request, func, arg_spec, arg_name, args_def, config):
                       arg_name,
                       _get_parameter_str(args_def)
                   )
-            Logger.get(config.app_id).warning(msg)
+            Logger.current().warning(msg)
         # 在 session 未启用时，其值为 None
         return request.session
     return None
@@ -384,7 +396,7 @@ def _fill_injections(request, func, injection_args, actual_args, config):
         msg = 'Injection name "%s" not found.' % injection_name
         if config.debug:
             msg = '%s\n\t%s' % (get_func_info(func), msg)
-        Logger.get(config.app_id).error(msg)
+        Logger.current().error(msg)
         return ServerError(msg) if config.debug else ServerError()
     return None
 
@@ -462,7 +474,7 @@ def _get_actual_args(request: HttpRequest, func, args_def: OrderedDict, config:
         # 未找到参数
         if use_default is None:
             msg = 'Missing required argument "%s".' % arg_name
-            Logger.get(config.app_id).warning(msg)
+            Logger.current().warning(msg)
             return BadRequest(msg)
 
         # 使用默认值
@@ -503,7 +515,7 @@ def _get_actual_args(request: HttpRequest, func, args_def: OrderedDict, config:
     variable_arg_keys = variable_args.keys()
     msg = 'Unknown argument(s) found: "%s", Parameters: (%s).' \
           % (','.join(variable_arg_keys), _get_parameter_str(args_def))
-    Logger.get(config.app_id).warning(msg)
+    Logger.current().warning(msg)
     if not config.debug:
         msg = 'Unknown argument(s) found: %s.' % ','.join(variable_arg_keys)
     return BadRequest(msg)
