@@ -1,7 +1,7 @@
-import pickle
 import time
 from abc import ABC, abstractmethod
 from threading import Timer
+from types import FunctionType
 from typing import List, Optional
 
 from .session import HttpSession
@@ -13,28 +13,34 @@ class ISessionProvider(ABC):
     此类不可被实例化
     """
 
-    def __init__(self, expired: int):
+    def __init__(self, expired: int, check_interval: int, auto_clear: bool, on_expired: FunctionType = None):
         """
 
         :param expired: 过期时长，单位为秒，默认为 10分钟。指定为 0表示不会自动过期
+        :param check_interval: 检查 session 是否过期的周期，单位为秒，指定为 0 时不检查
+        :param auto_clear: 是否在停止/启动时，自动清空 session 存储
+        :param on_expired: 在 session 过期时，触发
         """
         from restfx.util import Logger
-        from restfx import globs
-        self._logger = Logger.get(globs.current_app.id)
+        self.logger = Logger.current()
+        self.auto_clear = auto_clear
 
         self.expired = 10 * 60 if expired is None else expired
+        self.on_expired = on_expired
 
         # 不会过期，不用启动定时器
-        if self.expired > 0:
+        if self.expired > 0 and check_interval > 0:
             # 每 5 秒执行一次检查
-            self.timer = Timer(5, self._drop_expire_session)
+            self.timer = Timer(check_interval, self.drop_expired_session)
             self.timer.start()
 
-    def _drop_expire_session(self):
+    def drop_expired_session(self):
         time_before = time.time() - self.expired
         expired_sessions = self.get_expired_session(time_before)
         for session_id in expired_sessions:
-            # self._logger.debug('Drop expired session: ' + session_id)
+            if self.on_expired:
+                self.on_expired(self.get(session_id))
+            # self.logger.debug('Drop expired session: ' + session_id)
             self.remove(session_id)
 
     def is_expired(self, session: HttpSession) -> bool:
@@ -55,7 +61,7 @@ class ISessionProvider(ABC):
         :param time_before: 在此时间之前的 session 即为过期
         :return:
         """
-        pass
+        raise NotImplemented()
 
     @abstractmethod
     def get(self, session_id: str) -> Optional[HttpSession]:
@@ -64,7 +70,7 @@ class ISessionProvider(ABC):
         :param session_id:
         :return:
         """
-        pass
+        raise NotImplemented()
 
     @abstractmethod
     def set(self, session: HttpSession):
@@ -73,7 +79,7 @@ class ISessionProvider(ABC):
         :param session:
         :return:
         """
-        pass
+        raise NotImplemented()
 
     @abstractmethod
     def exists(self, session_id: str) -> bool:
@@ -82,7 +88,7 @@ class ISessionProvider(ABC):
         :param session_id:
         :return:
         """
-        pass
+        raise NotImplemented()
 
     @abstractmethod
     def remove(self, session_id: str):
@@ -91,8 +97,16 @@ class ISessionProvider(ABC):
         :param session_id:
         :return:
         """
+        raise NotImplemented()
 
     @abstractmethod
+    def clear(self):
+        """
+        清空所有 session
+        :return:
+        """
+        raise NotImplemented()
+
     def dispose(self):
         """
         回收 session provider
@@ -100,38 +114,21 @@ class ISessionProvider(ABC):
         """
         self.timer.cancel()
         self.timer.join()
+        if self.auto_clear:
+            self.clear()
 
 
 class IDbSessionProvider(ISessionProvider):
-    def __init__(self, pool_options: dict, expired: int):
-        super().__init__(expired)
+    def __init__(self, db_options: dict, expired: int, check_interval: int, auto_clear=False,
+                 on_expired: FunctionType = None):
+        super().__init__(expired, check_interval, auto_clear, on_expired)
 
-        from dbutils.pooled_db import PooledDB
-        self.pool_option = pool_options
-        self.pool = PooledDB(**pool_options)
-        # fixme 如果启动时数据库无法连接，也应该允许程序启动，而不是抛出异常
-        # 更好的做法是在第一次执行 execute 时作此检查
-        if not self.table_exists():
-            self.create_table()
+        self.db_options = db_options
+        self.is_db_available = False
 
-    def connect(self, shareable=True):
-        return self.pool.connection(shareable)
-
-    @abstractmethod
-    def table_exists(self) -> bool:
-        """
-        判断 session 表是否存在
-        :return:
-        """
-        pass
-
-    @abstractmethod
-    def create_table(self):
-        """
-        创建 session 表
-        :return:
-        """
-        pass
+    def drop_expired_session(self):
+        if self.is_db_available:
+            super(IDbSessionProvider, self).drop_expired_session()
 
     def parse(self, data: dict) -> HttpSession:
         """
@@ -139,6 +136,7 @@ class IDbSessionProvider(ISessionProvider):
         :param data:
         :return:
         """
+        import pickle
         session = HttpSession(data['id'], self.set, self.remove)
         session.creation_time = int(data['creation_time'])
         session.last_access_time = int(data['last_access_time'])
@@ -147,6 +145,7 @@ class IDbSessionProvider(ISessionProvider):
         return session
 
     def set(self, session: HttpSession):
+        import pickle
         self.upsert(session.id,
                     session.creation_time,
                     session.last_access_time,
@@ -154,9 +153,7 @@ class IDbSessionProvider(ISessionProvider):
 
     @abstractmethod
     def upsert(self, session_id: str, creation_time: float, last_access_time: float, store: bytes):
-        pass
+        raise NotImplemented()
 
-    @abstractmethod
     def dispose(self):
-        self.pool.close()
         super(IDbSessionProvider, self).dispose()
